function mat_v = disp_neurons(II, duration, s_r)
%   mat_v = disp_neurons(II, duration, s_r);
%
%   Routine to display neuron spikes according to the different parameter
%   sets reported by Izhikevich 2003:
%   
%   RS: regular spiking neurons
%   IB: intrinsically bursting neurons
%   CH: chattering neurons
%   FS: fast spiking neurons
%   TC1: thalamo cortical neurons, when excited
%   TC2: thalamo cortical neurons, when recovering from inhibitor activity
%   RZ: resonating neurons
%   LTS: Low-threshold spiking neurons
%   
%   INPUT:
%   II   = External current pattern/value;
%   duration = temporal support of the simulation {s};
%   s_r  = Sampling rate {samples/s};
%   
%   
%   Recommendation 2: if you want to input an external input pattern, it
%   needs to be s_r*duration long.
%
%   OUTPUT:
%   mat_v [numsamples x 9]: 
%       first column - temporal axis, 
%       columns 2 to 9 - v time series for each neuron type
%
%   DEPENDENCIES:
%   izkv.m
%   
%   REFERENCES:
%   E.M. Izhikevich, Simple model of spiking neurons, IEEE Trans Neur Net
%   14(6), 1569-1573
%
%   This routine was written by:
%   Maurizio Schmid, PhD <schmid@uniroma3.it>
%   BioLab?, Dept Applied Electronics, Roma Tre University, Italy
%   
%   Last Updated: Mar 31, 2011
%   Please retain the author names, and give acknowledgement where necessary.
%   The author does not assume any responsibility related to the use
%   of this code, and does not guarantee its correctness.
%:
%

close all
in_c1 = [-70,-14];
in_c2 = [-64.4,-16.1];
in_c3 = [-62.5,-16.25];

t_axis = (1 : duration * s_r)./s_r;


[v_RS] = spiking_neuron(in_c1, duration, 0.02, 0.2, -65, 8, II, s_r, 0);
[v_IB] = spiking_neuron(in_c1, duration, 0.02, 0.2, -55, 4, II, s_r, 0);
[v_CH] = spiking_neuron(in_c1, duration, 0.02, 0.2, -50, 2, II, s_r, 0);
[v_FS] = spiking_neuron(in_c1, duration, 0.1, 0.2, -65, 2, II, s_r, 0);

[v_TC1] = spiking_neuron(in_c2, duration, 0.02, 0.25, -65, 0.05, II, s_r, 0);
II1=-II;
[v_TC2] = spiking_neuron(in_c2, duration, 0.02, 0.25, -65, 0.05, II1, s_r, 0);
[v_RZ] = spiking_neuron(in_c3, duration, 0.1, 0.26, -65, 2, II, s_r, 0);
[v_LTS] = spiking_neuron(in_c2, duration, 0.02, 0.25, -65, 2, II, s_r, 0);

mat_v = [t_axis', v_RS, v_IB, v_CH, v_FS, v_TC1, v_TC2, v_RZ, v_LTS];

figure
subplot(241), plot(t_axis,v_RS), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('RS'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(242), plot(t_axis,v_IB), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('IB'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(243), plot(t_axis,v_CH), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('CH'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(244), plot(t_axis,v_FS), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('FS'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(245), plot(t_axis,v_TC1), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('TC+'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(246), plot(t_axis,v_TC2), hold on, plot(t_axis,40+(10*II1/max(abs(II1))),'k'), hold off, title('TC-'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(247), plot(t_axis,v_RZ), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('RZ'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')
subplot(248), plot(t_axis,v_LTS), hold on, plot(t_axis,40+(10*II/max(II)),'k'), hold off, title('LTS'), axis([0,t_axis(end),-80,50]), xlabel('(ms)'), ylabel('mV')


