function [vv,uu,time_axis] = izkv(varargin)
%[v,u,time] = izkv(in_c, time, aa, bb, cc, dd, II, s_r, show)
%
%   Routine to simulate spiking neurons behaviour according to the model
%   by Izhikevich 2003:
%
%   v' = 0.04v^2 + 5v + 140 -u + I
%   u' = a(bv-u)
%   
%   if v > 30 mV, then: v = c, u = u + d
%   
%   INPUT:
%   in_c = initial conditions for u & v {} [1 x 2] (default = [-70, -14]);
%   time = temporal support of the simulation {s} [1 x 1] (default = 1 s);
%   aa   = a parameter of the model {  } [1 x 1] (default = 0.02);
%   bb   = b parameter of the model {  } [1 x 1] (default = 0.2);
%   cc   = c parameter of the model {mV} [1 x 1] (default = -65 mV);
%   dd   = d parameter of the model (  } [1 x 1] (default = 2);
%   II   = External current value  (  } [undefined] (default = 0);
%   s_r  = Sampling rate {samples/s} [1 x 1] (default = 10000 samples/s)
%   show = binary variable (1 to show behaviour, no show otherwise)
%   
%   Recommendation 1: omit or leave empty brackets for default
%   
%   Recommendation 2: if you want to input an external input pattern, it
%   needs to be s_r*time long (with default parameters, 10000).
%
%   OUTPUT:
%   v,u = time series of v,u  [numsamples x 1];
%   time = temporal axis [numsamples x 1];
%
%   DEPENDENCIES:
%   none
%   
%   REFERENCES:
%   E.M. Izhikevich, Simple model of spiking neurons, IEEE Trans Neur Net
%   14(6), 1569-1573
%
%   This routine was written by:
%   Maurizio Schmid, PhD <schmid@uniroma3.it>
%   BioLab?, Dept Applied Electronics, Roma Tre University, Italy
%   
%   Last Updated: Mar 25, 2011
%   Please retain the author names, and give acknowledgement where necessary.
%   The author does not assume any responsibility related to the use
%   of this code, and does not guarantee its correctness.
%

%%   Phase 1: Initialize data:


%default values are used if no value is reported as input
default_binary = ones(1, 9);
for pp = 1:length(varargin)
    if ~isempty(varargin{pp})
      default_binary(pp) = 0;
    end
end


if default_binary(9)
    show = 0;
else
    show = varargin{9};
end
if default_binary(8)
    s_r = 10000;
else
    s_r = varargin{8};
end
if default_binary(7)
    II_tmp = 0;
else
    II_tmp = varargin{7};
end
if default_binary(6)
    dd = 2;
else
    dd = varargin{6};
end
if default_binary(5)
    cc = -65;
else
    cc = varargin{5};
end
if default_binary(4)
    bb = 0.2;
else
    bb = varargin{4};
end
if default_binary(3)
    aa = 0.02;
else
    aa = varargin{3};
end
if default_binary(2)
    time = 1;
else
    time = varargin{2};
end
if default_binary(1)
    in_c = [-70, -14];
else
    in_c = varargin{1};
end

n_samples = s_r * time;

%check whether I is a single value or a vector: if single value, create
%costant vector accordingly

if length(II_tmp)==1
    II = II_tmp*ones(1,n_samples);
else
    II = II_tmp;
end



vv = zeros(n_samples,1);
uu = zeros(n_samples,1);

delta_t = 1/s_r;

vv(1) = in_c(1);
uu(1) = in_c(2);

%% Phase 2: run the model
for jj = 2 : n_samples
    vv(jj) = vv(jj - 1) + delta_t * 1000 * (0.04 * vv(jj-1).^2 + 5 * vv(jj-1) + 140 - uu(jj-1) + II(jj-1));
    uu(jj) = uu(jj - 1) + delta_t * 1000 * (aa * (bb * vv(jj-1) - uu(jj-1)));
    
    if vv(jj) > 30
        vv(jj) = cc;
        uu(jj) = uu(jj) + dd;
    end
end
time_axis= (1:n_samples)./s_r;
%% Phase 3: draw the trajectories
if show
    subplot(2,2,[1 3]), plot(vv,uu,'LineWidth',3), xlabel('v'), ylabel('u')
    axis([-100, 50, -30, 30])
    subplot(2,2,2), plot(time_axis,vv,'LineWidth',1), xlabel('time (s)'), title('v')
    subplot(2,2,4), plot(time_axis,uu,'LineWidth',1), xlabel('time (s)'), title('u')
    
end